==> models_weebi-1.0.22.tar.gz: lib/src/reports/report_stock_article_calibre.dart <==
library report_stock_product;

import 'package:models_weebi/base.dart' show ArticleCalibreAbstract;
import 'package:models_weebi/utils.dart' show DateRange;
import 'package:models_weebi/src/closings/abstract/stock_quantity.dart';
import 'package:models_weebi/src/reports/report_stock_article.dart';

class ReportStockProduct extends ArticleCalibreAbstract<ReportStockArticle>
    implements DateRange, StockQuantityAbstract {
  @override
  double initialQtCl = 0.0; // closing initial qt
  @override
  double finalQtCl = 0.0; // closing final qt
  double varQtTickets = 0.0; // we do not have initialQtTickets only final
  // double initialQtTickets = 0.0;
  // double get finalQtSuper => (finalQtCl ?? 0.0) + (finalQtTickets ?? 0.0);
  double get qtVariationDuringATimeRangeSuper =>
      (varQtTickets) +
      (finalQtCl - initialQtCl); // variation archives + tickets
  // * toRuminate weight reconciliation incompatible yet

  @override
  DateTime start;
  @override
  DateTime end;

  ReportStockProduct({
    required super.id,
    required super.title,
    required this.start,
    required this.end,
    required this.initialQtCl,
    required this.finalQtCl,
    required this.varQtTickets,
    List<ReportStockArticle>? articles,
    // ignore: missing_required_param
  }) : super(
          articles: articles ?? [],
          status: true,
          creationDate: DateTime.now(),
        );

  @override
  Map<String, dynamic> toMap() {
    return {
      'id': id,
      'title': title,
      'startDate': start.toIso8601String(),
      'endDate': end.toIso8601String(),
      'initialQtCl': initialQtCl,
      'finalQtCl': finalQtCl,
      'finalQtTickets': varQtTickets,
      // articles to be added
    };
  }
}

==> models_weebi-1.1.2.tar.gz: lib/src/reports/report_stock_article_calibre.dart <==
library report_stock_product;

import 'package:models_weebi/abstracts.dart' show CalibreAbstract;
import 'package:models_weebi/utils.dart' show DateRange;
import 'package:models_weebi/src/closings/abstract/stock_quantity.dart';
import 'package:models_weebi/src/reports/report_stock_article.dart';

class ReportStockArtCalibre extends CalibreAbstract<ReportStockArticle>
    implements DateRange, StockQuantityAbstract {
  @override
  double initialQtCl = 0.0; // closing initial qt
  @override
  double finalQtCl = 0.0; // closing final qt
  double varQtTickets = 0.0; // we do not have initialQtTickets only final
  // double initialQtTickets = 0.0;
  // double get finalQtSuper => (finalQtCl ?? 0.0) + (finalQtTickets ?? 0.0);
  double get qtVariationDuringATimeRangeSuper =>
      (varQtTickets) +
      (finalQtCl - initialQtCl); // variation archives + tickets
  // * toRuminate weight reconciliation incompatible yet

  @override
  DateTime start;
  @override
  DateTime end;

  ReportStockArtCalibre({
    required super.id,
    required super.title,
    required this.start,
    required this.end,
    required this.initialQtCl,
    required this.finalQtCl,
    required this.varQtTickets,
    List<ReportStockArticle>? articles,
    // ignore: missing_required_param
  }) : super(
          articles: articles ?? [],
          status: true,
          creationDate: DateTime.now(),
        );

  @override
  Map<String, dynamic> toMap() {
    return {
      'id': id,
      'title': title,
      'startDate': start.toIso8601String(),
      'endDate': end.toIso8601String(),
      'initialQtCl': initialQtCl,
      'finalQtCl': finalQtCl,
      'finalQtTickets': varQtTickets,
      // articles to be added
    };
  }
}
